RandomBoardGen

Struct RandomBoardGen 

pub struct RandomBoardGen<R: Rng> { /* private fields */ }
Random world map board generator

Implementations

Source

impl RandomBoardGen<StdRng>

pub fn from_seed(seed: u64) -> Self

Create a new random map generator. It’s internal random number generator is initialized by the given seed. Standard random number generator is used.

Source

impl<R: Rng> RandomBoardGen<R>

pub fn gen( &mut self, resolution: Option<Resolution>, width: Option<usize>, height: Option<usize>, ) -> Result<Board<'static>>

Most generic method to generate a random map. When resolution is None, the resolution is determined from its size. When width and/or height are None they will be determined from the terminal size. In the case, when terminal size cannot be obtained, this method returns an error.

pub fn gen_auto(&mut self, width: usize, height: usize) -> Board<'static>

Generate a random map of given width and height. Resolution is automatically determined from its size.

  • When width and height are lower than 15: low resolution
  • When width and height are lower than 120: middle resolution
  • Otherwise: high resolution
pub fn gen_small(&mut self, width: usize, height: usize) -> Board<'static>

Generate a low resolution random map of given width and height.

pub fn gen_middle(&mut self, width: usize, height: usize) -> Board<'static>

Generate a middle resolution random map of given width and height.

pub fn gen_large(&mut self, width: usize, height: usize) -> Board<'static>

Generate a large resolution random map of given width and height.